@@ -37,7 +37,7 @@ except ImportError:
     import configparser as ConfigParser
 
 
-__version__ = '0.11'
+__version__ = '0.12'
 __author__ = 'Marius Gedminas <marius@gedmin.as>'
 __licence__ = 'GPL v2 or later' # or ask me for MIT
 __url__ = 'https://github.com/mgedmin/check-manifest'
@@ -333,12 +333,19 @@ SUGGESTIONS = [(re.compile(pattern), suggestion) for pattern, suggestion in [
     ('^([^/]+[.](cfg|ini))$',       r'include \1'),
     ('^([.]travis[.]yml)$',         r'include \1'),
     ('^([A-Z]+)$',                  r'include \1'),
+    ('^(Makefile)$',                r'include \1'),
     ('^[^/]+[.](txt|rst|py)$',      r'include *.\1'),
     ('^([a-zA-Z_][a-zA-Z_0-9]*)/'
      '.*[.](py|zcml|pt|mako|xml|html|txt|rst|css|png|jpg|dot|po|pot|mo|ui|desktop|bat)$',
                                     r'recursive-include \1 *.\2'),
     ('^([a-zA-Z_][a-zA-Z_0-9]*)/(Makefile)$',
                                     r'recursive-include \1 \2'),
+    # catch-all rules that actually cover some of the above; somewhat
+    # experimental: I fear false positives
+    ('^([a-zA-Z_0-9]+)$',           r'include \1'),
+    ('^[^/]+[.]([a-zA-Z_0-9]+)$',   r'include *.\1'),
+    ('^([a-zA-Z_][a-zA-Z_0-9]*)/.*[.]([a-zA-Z_0-9]+)$',
+                                    r'recursive-include \1 *.\2'),
 ]]
 
 
@@ -509,10 +516,16 @@ def zest_releaser_check(data):
     http://zestreleaser.readthedocs.org/en/latest/entrypoints.html
     """
     from zest.releaser.utils import ask
+    source_tree = data['workingdir']
+    if not is_package(source_tree):
+        # You can use zest.releaser on things that are not Python packages.
+        # It's pointless to run check-manifest in those circumstances.
+        # See https://github.com/mgedmin/check-manifest/issues/9 for details.
+        return
     if not ask("Do you want to run check-manifest?"):
         return
     try:
-        if not check_manifest(data['workingdir']):
+        if not check_manifest(source_tree):
             if not ask("MANIFEST.in is not in order. "
                        " Do you want to continue despite that?", default=False):
                 sys.exit(1)
